@@ -8,13 +8,15 @@
 
 knitr::knit("vignettes/ergast-data-analysis.Rmd.orig", "vignettes/ergast-data-analysis.Rmd")
 knitr::knit("vignettes/introduction.Rmd.orig", "vignettes/introduction.Rmd")
+knitr::knit("vignettes/plotting-turn-info.Rmd.orig", "vignettes/plotting-turn-info.Rmd")
 cat("Successfully compiled vignettes. Now moving figures to ./vignettes")
 
-vig_images<-list.files(pattern = "(ergast-data-analysis|introduction)-[(a-z)(A-Z)(0-9)_]*-1.png")
+vig_images<-list.files(pattern = "(ergast-data-analysis|introduction|plotting-turn-info)-[(a-z)(A-Z)(0-9)_]*-1.png")
 file.copy(paste0("./", vig_images),
           paste0("./vignettes/", vig_images), overwrite = T)
 unlink(vig_images)
-# If you have the optimpng tool installed on your system run this to reduce png size
+# If you have the optipng tool installed on your system run this to reduce png size
+# xfun::optipng("./vignettes/")
 
 # Optional
 devtools::build_vignettes()
